# Mappedin JS

## Resources

- [Mappedin Developer Portal](https://developer.mappedin.com)
- [Releases and Roadmap](https://developer.mappedin.com/docs/roadmap)
- [Getting Started Guide](https://developer.mappedin.com/web-sdk/5.0/getting-started)
- [API Reference](https://developer.mappedin.com/web-sdk/5.0/api-reference)
- [Demo Keys & Maps](https://developer.mappedin.com/docs/demo-keys-and-maps)
- [License](https://info.mappedin.com/terms/sdk)

## Usage

### Installation

`npm install @mappedin/mappedin-js`

or

`yarn add @mappedin/mappedin-js`

### Getting Started

```javascript
import { getVenue, showVenue, E_SDK_EVENT } from '@mappedin/mappedin-js';
import '@mappedin/mappedin-js/lib/index.css';

async function init() {
	const venueData = await getVenue({
		clientId: '<clientId>',
		clientSecret: '<clientSecret>',
		venue: '<venue>',
	});

	const mapView = await showVenue(document.getElementById('mappedin-map'), venueData);
	mapView.FloatingLabels.labelAllLocations();
	mapView.addInteractivePolygonsForAllLocations();
	mapView.on(E_SDK_EVENT.CLICK, ({ polygons }) => {
		console.log(`Polygon with id ${polygons[0].id} clicked!`);
	});
}
document.addEventListener('DOMContentLoaded', init);
```

For full documentation, read our [Getting Started guide on the Developer Portal](https://developer.mappedin.com/web-sdk/5.0/getting-started). Developers using React or Angular should follow our [Using React](https://developer.mappedin.com/web-sdk/5.0/react) or [Using Angular](https://developer.mappedin.com/web-sdk/5.0/angular) guides.
